..
    This file is part of Invenio.
    Copyright (C) 2016-2021 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Changes
=======


Version 2.3.1 (released 2021-06-10)
-----------------------------------

- Remove invenio dependencies to depend only on rdm-records.


Version 2.3.0 (released 2021-05-28)
-----------------------------------

- Improve visual feedback when changing permissions.
- Align facets with new records-resources faceting paradigm.


Version 2.2.5 (released 2021-04-29)
-----------------------------------

- Initial public release.
